//=============================================================================
// MyCrosshairs
//=============================================================================
// This example project expects UT2004 v3204 or later.
//
// How to use this:
// 1. Create a texture package in UnrealEd or with UCC BatchImport, which
//    contains all your new crosshairs. It's probably a good idea to stick to
//    the same dimensions as UT2004's own crosshair textures.
// 2. Rename this class (i.e. the file itself and the class name in the
//    "class ... extends ...;" line below) and its package so it reflects the
//    name of your crosshair pack. Make sure the code package doesn't have the
//    same name as the crosshait texture pckage, but try to keep them similar,
//    for example "MyCrosshairPack.u" and "MyCrosshairTextures.utx".
// 3. Change MyCrosshairTextures.utx below to the name of the texture package
//    containing your crosshair textures.
// 4. Add all crosshair textures to the crosshair list in the defaultproperties
//    section and give them unique FriendlyNames. Make sure the names aren't
//    used by other crosshair packs or the default crosshairs, because in that
//    case the user will see multiple crosshairs with the same name in the
//    crosshair list.
// 5. Compile this file. I suggest using UMake for this, the UMake project file
//    is already included. You can get UMake at:
//    http://wiki.beyondunreal.com/wiki/UMake
//    Check the project setup before compiling and make sure the only packages
//    listed are Core and Engine. (Uncheck all others)
//=============================================================================


class MyCrosshairs extends CrosshairPack;


//=============================================================================
// Imports
//=============================================================================

// The path name below is relative to the UT2004\MyCrosshairPack directory,
// i.e. the one that contains the Classes directory with this .UC file in it.

#exec obj load file=..\Textures\MyCrosshairTextures.utx


//=============================================================================
// Default properties
//=============================================================================

defaultproperties
{
  Crosshair(0)=(FriendlyName="My Crosshair 1",CrosshairTexture=Texture'MyCrosshairTextures.MyCrosshair1')
  Crosshair(1)=(FriendlyName="My Crosshair 2",CrosshairTexture=Texture'MyCrosshairTextures.MyCrosshair2')
}
